@@ -53,7 +53,7 @@ class HTTPNotAcceptableAPIVersion(exc.HTTPNotAcceptable):
             except ValueError:
                 pass
 
-            links = {'rel': 'help', 'href': 'http://developer.openstack.org'
+            links = {'rel': 'help', 'href': 'http://docs.openstack.org'
                      '/api-guide/compute/microversions.html'}
 
             err['max_version'] = self.max_version
