@@ -21,6 +21,7 @@ import sys
 
 import requests
 
+
 HEAT_PARAMS_PATH = '/etc/sysconfig/heat-params'
 PUBLIC_IP_URL = 'http://169.254.169.254/latest/meta-data/public-ipv4'
 CERT_DIR = '/etc/docker'
@@ -67,17 +68,23 @@ def create_dirs():
 
 
 def _get_public_ip():
-    return requests.get(PUBLIC_IP_URL).text
+    return requests.get(PUBLIC_IP_URL, timeout=60).text
 
 
 def _build_subject_alt_names(config):
-    subject_alt_names = [
-        'IP:%s' % _get_public_ip(),
-        'IP:%s' % config['API_IP_ADDRESS'],
-        'IP:%s' % config['SWARM_NODE_IP'],
-        'IP:%s' % config['SWARM_API_IP'],
-        'IP:127.0.0.1'
-    ]
+    ips = {
+        config['SWARM_NODE_IP'],
+        config['SWARM_API_IP'],
+        '127.0.0.1',
+    }
+    # NOTE(mgoddard): If floating IP is disabled, these can be empty.
+    public_ip = _get_public_ip()
+    if public_ip:
+        ips.add(public_ip)
+    api_ip = config['API_IP_ADDRESS']
+    if api_ip:
+        ips.add(api_ip)
+    subject_alt_names = ['IP:%s' % ip for ip in ips]
     return ','.join(subject_alt_names)
 
 
@@ -88,16 +95,17 @@ def write_ca_cert(config, verify_ca):
                'OpenStack-API-Version': 'container-infra latest'}
     ca_cert_resp = requests.get(cluster_cert_url,
                                 headers=headers,
-                                verify=verify_ca)
+                                verify=verify_ca, timeout=60)
 
     with open(CA_CERT_PATH, 'w') as fp:
         fp.write(ca_cert_resp.json()['pem'])
 
 
 def write_server_key():
-    subprocess.call(['openssl', 'genrsa',
-                     '-out', SERVER_KEY_PATH,
-                     '4096'])
+    subprocess.check_call(
+        ['openssl', 'genrsa',
+         '-out', SERVER_KEY_PATH,
+         '4096'])
 
 
 def _write_csr_config(config):
@@ -110,13 +118,14 @@ def _write_csr_config(config):
 
 def create_server_csr(config):
     _write_csr_config(config)
-    subprocess.call(['openssl', 'req', '-new',
-                     '-days', '1000',
-                     '-key', SERVER_KEY_PATH,
-                     '-out', SERVER_CSR_PATH,
-                     '-reqexts', 'req_ext',
-                     '-extensions', 'req_ext',
-                     '-config', SERVER_CONF_PATH])
+    subprocess.check_call(
+        ['openssl', 'req', '-new',
+         '-days', '1000',
+         '-key', SERVER_KEY_PATH,
+         '-out', SERVER_CSR_PATH,
+         '-reqexts', 'req_ext',
+         '-extensions', 'req_ext',
+         '-config', SERVER_CONF_PATH])
 
     with open(SERVER_CSR_PATH, 'r') as fp:
         return {'cluster_uuid': config['CLUSTER_UUID'], 'csr': fp.read()}
@@ -132,7 +141,7 @@ def write_server_cert(config, csr_req, verify_ca):
     csr_resp = requests.post(cert_url,
                              data=json.dumps(csr_req),
                              headers=headers,
-                             verify=verify_ca)
+                             verify=verify_ca, timeout=60)
 
     with open(SERVER_CERT_PATH, 'w') as fp:
         fp.write(csr_resp.json()['pem'])
@@ -163,7 +172,8 @@ def get_user_token(config, verify_ca):
     creds = creds_str % params
     headers = {'Content-Type': 'application/json'}
     url = config['AUTH_URL'] + '/auth/tokens'
-    r = requests.post(url, headers=headers, data=creds, verify=verify_ca)
+    r = requests.post(url, headers=headers, data=creds, verify=verify_ca,
+                      timeout=60)
     config['USER_TOKEN'] = r.headers['X-Subject-Token']
     return config
 
